@@ -119,7 +119,7 @@
 #'
 #' @details The spatial linear model for point-referenced data
 #'   (i.e., geostatistical model) can be written as
-#'   \eqn{y = X \beta + \tau + \epsilon}, where X is the fixed effects design
+#'   \eqn{y = X \beta + \tau + \epsilon}, where \eqn{X} is the fixed effects design
 #'   matrix, \eqn{\beta} are the fixed effects, \eqn{\tau} is random error that is
 #'   spatially dependent, and \eqn{\epsilon} is random error that is spatially
 #'   independent. Together, \eqn{\tau} and \eqn{\epsilon} are modeled using
@@ -147,7 +147,7 @@
 #'     \item{magnetic: }{\eqn{(1 + \eta^2)^{-1.5}}}
 #'     \item{matern: }{\eqn{2^{1 - extra}/ \Gamma(extra) * \alpha^{extra} * Bk(\alpha, extra)}, \eqn{\alpha = (2extra * \eta)^{0.5}}, Bk is Bessel-K function with order \eqn{1/5 \le extra \le 5}}
 #'     \item{cauchy: }{\eqn{(1 + \eta^2)^{-extra}}, \eqn{extra > 0}}
-#'     \item{pexponential: }{\eqn{exp(h^{extra/range)}}, \eqn{0 < extra \le 2}}
+#'     \item{pexponential: }{\eqn{exp(h^{extra}/range)}, \eqn{0 < extra \le 2}}
 #'     \item{none: }{\eqn{0}}
 #'   }
 #'
@@ -191,8 +191,8 @@
 #' \code{local} Details: The big data approximation works by sorting observations into different levels
 #'   of an index variable. Observations in different levels of the index variable
 #'   are assumed to be uncorrelated for the purposes of model fitting. Sparse matrix methods are then implemented
-#'   for significant computational gains. Parallelization further speeds up
-#'   computations. Both the \code{"random"} and \code{"kmeans"} values of \code{method}
+#'   for significant computational gains. Parallelization generally further speeds up
+#'   computations when data sizes are larger than a few thousand. Both the \code{"random"} and \code{"kmeans"} values of \code{method}
 #'   in \code{local} have random components. That means you may get slightly different
 #'   results when using the big data approximation and rerunning \code{splm()} with the same code. For consistent results,
 #'   either set a seed via \code{base::set.seed()} or specify \code{index} to \code{local}.
@@ -206,11 +206,11 @@
 #'   length one, the list has class \code{splm}. Many generic functions that
 #'   summarize model fit are available for \code{splm} objects, including
 #'   \code{AIC}, \code{AICc}, \code{anova}, \code{augment}, \code{coef},
-#'   \code{cooks.distance}, \code{deviance}, \code{fitted}, \code{formula},
+#'   \code{cooks.distance}, \code{covmatrix}, \code{deviance}, \code{fitted}, \code{formula},
 #'   \code{glance}, \code{glances}, \code{hatvalues}, \code{influence},
 #'   \code{labels}, \code{logLik}, \code{loocv}, \code{model.frame}, \code{model.matrix},
 #'   \code{plot}, \code{predict}, \code{print}, \code{pseudoR2}, \code{summary},
-#'   \code{terms}, \code{tidy}, \code{update}, and \code{vcov}. If
+#'   \code{terms}, \code{tidy}, \code{update}, \code{varcomp}, and \code{vcov}. If
 #'   \code{spcov_type} or \code{spcov_initial} are length greater than one, the
 #'   list has class \code{splm_list} and each element in the list has class
 #'   \code{splm}. \code{glances} can be used to summarize \code{splm_list}
@@ -384,7 +384,8 @@ splm <- function(formula, data, spcov_type, xcoord, ycoord, spcov_initial, estme
     xlevels = data_object$xlevels,
     is_sf = data_object$is_sf,
     sf_column_name = data_object$sf_column_name,
-    crs = data_object$crs
+    crs = data_object$crs,
+    diagtol = data_object$diagtol
   )
 
   new_output <- structure(output, class = "splm")
